@@ -9,8 +9,8 @@ from sklearn.preprocessing import MultiLabelBinarizer
 from tqdm.autonotebook import tqdm
 
 from .data_utils import count_tags
-from .domain import Case, Mask, MaskedParent, MaskRet, Trace
-from .model import StandaloneModel
+from .domain import THRESH, Case, Mask, MaskedParent, MaskRet, Trace
+from .model import StandaloneModel, label_output
 
 
 class MaskMaker:
@@ -29,12 +29,15 @@ class MaskMaker:
 
 
 class MaskExplainer:
-    def __init__(self, mlb: MultiLabelBinarizer, mask_maker: MaskMaker = None):
+    def __init__(
+        self, mlb: MultiLabelBinarizer, mask_maker: MaskMaker = None, thresh=None
+    ):
         if mask_maker is None:
             self.mask_maker = MaskMaker()
         else:
             self.mask_maker = mask_maker
         self.mlb = mlb
+        self.thresh = THRESH if thresh is None else thresh
 
     def explain(self, model: StandaloneModel, case: Case):
         origin_output = model.predict([case], tqdm_disable=True)
@@ -50,7 +53,7 @@ class MaskExplainer:
         def sort_col_descend(values, col):
             return np.argsort(values[:, col])[::-1]
 
-        pred = trace.origin_output >= 0.5
+        pred = label_output(trace.origin_output, self.thresh)
         bool_idx = pred[0]
         trace.important_change = (
             trace.origin_output[:, bool_idx] - trace.masked_outputs[:, bool_idx]
@@ -95,7 +98,9 @@ def plot_explanation(rets: List[MaskRet], dash=False):
     fig.show()
 
 
-def top_keywords(mask_explainer: MaskExplainer, model: StandaloneModel, cases, top_n=5):
+def top_keywords(
+    mask_explainer: MaskExplainer, model: StandaloneModel, cases, top_n=-1
+):
     rets = collect_rets(mask_explainer, model, cases)
     keywords = sum_keywords(rets, top_n)
     return refine_top(keywords, top_n)
@@ -127,7 +132,8 @@ def sum_keywords(rets, top_n=5):
 def refine_top(top, top_n=5):
     refine_ret = {}
     for k, v in top.items():
-        tmp = sorted(v.items(), key=lambda x: x[1], reverse=True)[:top_n]
+        crop_len = len(v) if top_n == -1 else top_n
+        tmp = sorted(v.items(), key=lambda x: x[1], reverse=True)[:crop_len]
         sum_ = sum(v for _, v in tmp)
         refine_ret[k] = [(k, v / sum_) for k, v in tmp]
     return refine_ret
