@@ -1,7 +1,7 @@
 import json
 import os
+import shutil
 from dataclasses import dataclass
-import   shutil 
 
 import dash
 import dash_html_components as html
@@ -12,15 +12,17 @@ from sklearn.preprocessing import MultiLabelBinarizer
 from . import io_utils, web_utils
 from .mask_explain import MaskExplainer, plot_explanation
 from .model import StandaloneModel
-from .validation import dimension_reduction_plot, get_tag_states
+from .validation import dimension_reduction_plot
+from tagc.validation import dimension_reduction
 
 URL = "https://gosheet-bqjlnzid4q-uc.a.run.app/add"
 
+
 @dataclass
 class WebConfig:
     dataset_p: str
     model_p: str
-    unlabelled_p:str
+    unlabelled_p: str
     state_p: str
 
     def init_static(self):
@@ -38,10 +40,12 @@ class WebConfig:
         os.remove(self.dataset_p)
         os.remove(self.unlabelled_p)
         os.remove(self.state_p)
+
+
 class Server:
     def __init__(self, web_config: WebConfig):
         self.dataset_p = web_config.dataset_p
-        self.model_p = web_config.model_p   
+        self.model_p = web_config.model_p
         self.unlabelled_p = web_config.unlabelled_p
         self.state_p = web_config.state_p
 
@@ -64,9 +68,8 @@ class Server:
         self.state = io_utils.load_state(self.state_p)
 
     def init_plot(self):
-        self.fig, self.dimension_reducer = dimension_reduction_plot(
-            self.state, method_n="tsne", n_components=2, dash=True
-        )
+        state_df = dimension_reduction(self.state, method_n="tsne", n_components=2)
+        self.fig = dimension_reduction_plot(state_df, n_components=2)
 
     def plot(self):
         app = self.app
